@@ -1,7 +1,9 @@
+import asyncio
 from starlette.applications import Starlette
 from starlette.responses import JSONResponse, PlainTextResponse
 from starlette.routing import Route
 from blexy.utils.config import GlobalConfig
+from blexy.utils.openmetrics import OpenMetricsAggregator
 
 
 async def homepage(request):
@@ -16,15 +18,17 @@ async def metrics(request):
     """
     Returns device readouts in OpenMetrics format
     """
-    out = []
-    for d in GlobalConfig.connected_devices():
-        if d.peripheral.waitForNotifications(5):
-            out.extend(d.open_metrics)
-    return PlainTextResponse("\n".join(out))
+    oma = OpenMetricsAggregator()
+    tasks = [d.asyncWaitForNotifications(5) for d in GlobalConfig.connected_devices()]
+    results = await asyncio.gather(*tasks)
+    for success, device in results:
+        if success:
+            oma.add_metrics(device.open_metrics)
+
+    return PlainTextResponse(oma.text)
 
 
 app = Starlette(
-    debug=True,
     routes=[
         Route("/", homepage),
         Route("/metrics", metrics),
